<p align="center">
  <img width = "140" src="https://github.com/j-faria/arvi/blob/main/docs/logo/logo.png?raw=true"/>
</p>


## Goals

- _Fast_:
  all `arvi` operations must be completed in under **1 second**

- _Reproducible_:
  **everyone** must be able to use `arvi`

- _Accurate_:
  `arvi` must always provide the **correct result**

